# About API Documentation

The following sections will provide automatically generated documentation of the spyral-utils API using the amazing [mkdocstrings](https://mkdocstrings.github.io/). These documents were generated using docstrings from the spyral-utils code itself, so should represent an up-to-date overview of the spyral-utils API.
